<script setup>
import { getCurrentInstance, ref, computed, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import EditView from './edit.vue'
import { formatMessage } from '@/utils/localeUtils.js';
import useTableSearch from '@/utils/tableUtils.jsx';
import ShowTaskDetlLogComponent from '@/components/taskLog/showTaskDetlLog/index.vue';
const context = getCurrentInstance()?.appContext.config.globalProperties;

const router = useRouter();

const TABLE_KEY = 'table-task';
let currentPage = 1;
let pageSize = 10;
const searchInput = ref("")
const searchParam = ref({
  taskNo: null,
  taskSts: null,
  taskType: null,
  originLoc: null,
  targetLoc: null,
  barcode: null,
})
const editChild = ref(null)
const showTaskDetlChild = ref(null)

const state = reactive({
  selectedRowKeys: [],
  loading: false,
});

let tableData = ref([]);
getPage();

const {
  getColumnSearchProps,
  handleResizeColumn,
} = useTableSearch();

const columns = [
  {
    title: formatMessage('db.man_task.task_no', '任务编号'),
    dataIndex: 'taskNo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('taskNo'),
  },
  {
    title: formatMessage('db.man_task.task_sts', '任务状态'),
    dataIndex: 'taskSts$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('taskSts$'),
  },
  {
    title: formatMessage('db.man_task.task_type', '任务类型'),
    dataIndex: 'taskType$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('taskType$'),
  },
  {
    title: formatMessage('db.man_task.io_pri', '优先级'),
    dataIndex: 'ioPri',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('ioPri'),
  },
  {
    title: formatMessage('db.man_task.origin_loc', '源库位'),
    dataIndex: 'originLoc',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('originLoc'),
  },
  {
    title: formatMessage('db.man_task.target_loc', '目标库位'),
    dataIndex: 'targetLoc',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('targetLoc'),
  },
  {
    title: formatMessage('db.man_task.origin_site', '源站点'),
    dataIndex: 'originSite',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('originSite'),
  },
  {
    title: formatMessage('db.man_task.target_site', '目标站点'),
    dataIndex: 'targetSite',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('targetSite'),
  },
  {
    title: formatMessage('db.man_task.barcode', '托盘码'),
    dataIndex: 'barcode',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('barcode'),
  },
  {
    title: formatMessage('db.man_task.status', '状态'),
    dataIndex: 'status$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('status$'),
  },
  {
    title: formatMessage('db.man_task.create_time', '添加时间'),
    dataIndex: 'createTime$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('createTime$'),
  },
  {
    title: formatMessage('db.man_task.create_by', '添加人员'),
    dataIndex: 'createBy$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('createBy$'),
  },
  {
    title: formatMessage('db.man_task.update_time', '修改时间'),
    dataIndex: 'updateTime$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('updateTime$'),
  },
  {
    title: formatMessage('db.man_task.update_by', '修改人员'),
    dataIndex: 'updateBy$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('updateBy$'),
  },
  {
    title: formatMessage('db.man_task.memo', '备注'),
    dataIndex: 'memo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('memo'),
  },
  {
    title: formatMessage('common.operation', '操作'),
    name: 'oper',
    dataIndex: 'oper',
    key: 'oper',
    fixed: 'right',
    width: 240,
  },
];


const hasSelected = computed(() => state.selectedRowKeys.length > 0);
const start = () => {
  state.loading = true;
  // ajax request after empty completing
  setTimeout(() => {
    state.loading = false;
    state.selectedRowKeys = [];
  }, 1000);
};
const onSelectChange = selectedRowKeys => {
  // console.log('selectedRowKeys changed: ', selectedRowKeys);
  state.selectedRowKeys = selectedRowKeys;
};

function getPage() {
  state.loading = true;

  post('/api/taskLog/page', {
    current: currentPage,
    pageSize: pageSize,
    condition: searchInput.value,
    _param: searchParam.value,
  }).then((resp) => {
    let result = resp.data;
    if (result.code == 200) {
      let data = result.data;
      tableData.value = data;

      state.loading = false;
    } else if (result.code === 401) {
      message.error(result.msg);
      logout()
    } else {
      message.error(result.msg);
    }
  })
}

const handleEdit = (item) => {
  editChild.value.open = true;
  editChild.value.formData = item == null ? editChild.value.initFormData : JSON.parse(JSON.stringify(item));
  editChild.value.isSave = item == null;
}

const handleDel = (rows) => {
  Modal.confirm({
    title: formatMessage('page.delete', '删除'),
    content: formatMessage('page.delete.confirm', '确定删除该项吗？'),
    maskClosable: true,
    onOk: async () => {
      const hide = message.loading(formatMessage('common.loading', '请求中'));
      try {
        post('/api/taskLog/remove/' + rows.map((row) => row.id).join(','), {}).then(resp => {
          let result = resp.data;
          if (result.code === 200) {
            message.success(result.msg);
          } else {
            message.error(result.msg);
          }
          getPage()
          hide()
        })
      } catch (error) {
        message.error(formatMessage('common.fail', '请求失败'));
      }
    },
  });
}

const handleExport = async (intl) => {
  postBlob('/api/taskLog/export', {
    condition: searchInput.value,
    _param: searchParam.value,
  }).then(result => {
    const blob = new Blob([result.data], { type: 'application/vnd.ms-excel' });
    window.location.href = window.URL.createObjectURL(blob);
    return true;
  })
};

const onSearch = () => {
  // console.log('search');
  getPage()
}

const onPageChange = (page, size) => {
  currentPage = page;
  pageSize = size;
  getPage();
}

function handleTableReload(value) {
  getPage()
}

const showDetl = (record) => {
  showTaskDetlChild.value.open = true;
  showTaskDetlChild.value.taskId = record.id;
}

const taskStsQueryList = ref(null);
taskStsQuery();
function taskStsQuery() {
  postForm('/api/taskSts/query', {}).then(resp => {
    let result = resp.data;
    taskStsQueryList.value = result.data;
  })
}
const taskTypeQueryList = ref(null);
taskTypeQuery();
function taskTypeQuery() {
  postForm('/api/taskType/query', {}).then(resp => {
    let result = resp.data;
    taskTypeQueryList.value = result.data;
  })
}

</script>

<script>
export default {
  name: '任务历史管理'
}
</script>

<template>
  <div>
    <EditView ref="editChild" @tableReload="handleTableReload" />
    <div class="table-header">
      <div>
        <a-input v-model:value="searchParam.taskNo" :placeholder="formatMessage('page.task.taskNo.input', '请输入任务编号')"
          style="width: 140px;margin-right: 10px;" />
        <a-select v-model:value="searchParam.taskSts"
          :placeholder="formatMessage('page.task.taskSts.select', '请选择任务状态')" style="width: 140px;margin-right: 10px;"
          show-search allowClear :options="taskStsQueryList" optionFilterProp="label" optionLabelProp="label">
        </a-select>
        <a-select v-model:value="searchParam.taskType"
          :placeholder="formatMessage('page.task.taskType.select', '请选择任务类型')" style="width: 140px;margin-right: 10px;"
          show-search allowClear :options="taskTypeQueryList" optionFilterProp="label" optionLabelProp="label">
        </a-select>
        <a-input v-model:value="searchParam.originLoc"
          :placeholder="formatMessage('page.task.originLoc.input', '请输入源库位')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.targetLoc"
          :placeholder="formatMessage('page.task.targetLoc.input', '请输入目标库位')"
          style="width: 140px;margin-right: 10px;" />
        <a-input v-model:value="searchParam.barcode" :placeholder="formatMessage('page.task.barcode.input', '请输入托盘码')"
          style="width: 140px;margin-right: 10px;" />

        <a-input-search v-model:value="searchInput" :placeholder="formatMessage('page.input', '请输入')"
          style="width: 200px;" @search="onSearch" />
      </div>
      <div class="table-header-right">
        <!-- <a-button @click="handleEdit(null)" type="primary">{{ formatMessage('page.add', '添加') }}</a-button> -->
        <a-button @click="handleExport">{{ formatMessage('page.export', '导出') }}</a-button>
      </div>
    </div>
    <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
      :data-source="tableData.records" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
      :pagination="{ total: tableData.total, onChange: onPageChange }"
      :scroll="{ y: 768, scrollToFirstRowOnChange: true }" :columns="columns" @resizeColumn="handleResizeColumn"
      :loading="state.loading">
      <template #bodyCell="{ column, text, record }">
        <template v-if="column.dataIndex === 'oper'">
          <div style="display: flex;justify-content: space-evenly;">
            <a-button type="link" primary @click="showDetl(record)">{{ formatMessage('page.task.orderDetl', '任务明细')
              }}</a-button>
          </div>
        </template>
      </template>
    </a-table>

    <ShowTaskDetlLogComponent ref="showTaskDetlChild" />
  </div>
</template>

<style></style>
